@@ -29,3 +29,12 @@ void Canvas::setPos(int x, int y){
   this->x=x;this->y=y;
 }
 
+int Canvas::getX(){
+  return x;
+}
+
+int Canvas::getY(){
+  return y;
+}
+
+
